==> mate-notification-daemon-1.26.0.tar.xz: mate-notification-daemon-1.26.0/src/capplet/mate-notification-applet-resources.c <==
#include <gio/gio.h>

#if defined (__ELF__) && ( __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 6))
# define SECTION __attribute__ ((section (".gresource.notification_applet"), aligned (8)))
#else
# define SECTION
#endif

#ifdef _MSC_VER
static const SECTION union { const guint8 data[409]; const double alignment; void * const ptr;}  notification_applet_resource_data = { {
  0107, 0126, 0141, 0162, 0151, 0141, 0156, 0164, 0000, 0000, 0000, 0000, 0000, 0000, 0000, 0000, 
  0030, 0000, 0000, 0000, 0344, 0000, 0000, 0000, 0000, 0000, 0000, 0050, 0007, 0000, 0000, 0000, 
  0000, 0000, 0000, 0000, 0000, 0000, 0000, 0000, 0002, 0000, 0000, 0000, 0003, 0000, 0000, 0000, 
  0004, 0000, 0000, 0000, 0006, 0000, 0000, 0000, 0007, 0000, 0000, 0000, 0113, 0120, 0220, 0013, 
  0002, 0000, 0000, 0000, 0344, 0000, 0000, 0000, 0004, 0000, 0114, 0000, 0350, 0000, 0000, 0000, 
  0354, 0000, 0000, 0000, 0265, 0144, 0045, 0040, 0006, 0000, 0000, 0000, 0354, 0000, 0000, 0000, 
  0007, 0000, 0114, 0000, 0364, 0000, 0000, 0000, 0370, 0000, 0000, 0000, 0324, 0265, 0002, 0000, 
  0377, 0377, 0377, 0377, 0370, 0000, 0000, 0000, 0001, 0000, 0114, 0000, 0374, 0000, 0000, 0000, 
  0000, 0001, 0000, 0000, 0276, 0102, 0047, 0030, 0001, 0000, 0000, 0000, 0000, 0001, 0000, 0000, 
  0016, 0000, 0114, 0000, 0020, 0001, 0000, 0000, 0024, 0001, 0000, 0000, 0201, 0321, 0040, 0031, 
  0000, 0000, 0000, 0000, 0024, 0001, 0000, 0000, 0005, 0000, 0114, 0000, 0034, 0001, 0000, 0000, 
  0040, 0001, 0000, 0000, 0062, 0253, 0136, 0330, 0003, 0000, 0000, 0000, 0040, 0001, 0000, 0000, 
  0010, 0000, 0166, 0000, 0050, 0001, 0000, 0000, 0215, 0001, 0000, 0000, 0000, 0113, 0055, 0223, 
  0004, 0000, 0000, 0000, 0215, 0001, 0000, 0000, 0006, 0000, 0114, 0000, 0224, 0001, 0000, 0000, 
  0230, 0001, 0000, 0000, 0157, 0162, 0147, 0057, 0004, 0000, 0000, 0000, 0141, 0160, 0160, 0154, 
  0145, 0164, 0057, 0000, 0003, 0000, 0000, 0000, 0057, 0000, 0000, 0000, 0000, 0000, 0000, 0000, 
  0156, 0157, 0164, 0151, 0146, 0151, 0143, 0141, 0164, 0151, 0157, 0156, 0163, 0057, 0000, 0000, 
  0005, 0000, 0000, 0000, 0155, 0141, 0164, 0145, 0057, 0000, 0000, 0000, 0006, 0000, 0000, 0000, 
  0155, 0145, 0156, 0165, 0056, 0170, 0155, 0154, 0244, 0000, 0000, 0000, 0001, 0000, 0000, 0000, 
  0170, 0332, 0263, 0311, 0115, 0315, 0053, 0315, 0054, 0111, 0315, 0125, 0310, 0113, 0314, 0115, 
  0265, 0125, 0162, 0311, 0367, 0313, 0057, 0161, 0311, 0054, 0056, 0051, 0055, 0112, 0122, 0360, 
  0004, 0212, 0053, 0051, 0044, 0046, 0227, 0144, 0346, 0347, 0241, 0112, 0051, 0051, 0350, 0333, 
  0161, 0331, 0240, 0351, 0015, 0050, 0112, 0115, 0113, 0055, 0112, 0315, 0113, 0116, 0055, 0106, 
  0323, 0212, 0044, 0203, 0125, 0247, 0143, 0122, 0176, 0151, 0011, 0232, 0036, 0260, 0030, 0130, 
  0065, 0000, 0225, 0036, 0070, 0062, 0000, 0050, 0165, 0165, 0141, 0171, 0051, 0160, 0141, 0156, 
  0145, 0154, 0057, 0000, 0001, 0000, 0000, 0000
} };
#else /* _MSC_VER */
static const SECTION union { const guint8 data[409]; const double alignment; void * const ptr;}  notification_applet_resource_data = {
  "\107\126\141\162\151\141\156\164\000\000\000\000\000\000\000\000"
  "\030\000\000\000\344\000\000\000\000\000\000\050\007\000\000\000"
  "\000\000\000\000\000\000\000\000\002\000\000\000\003\000\000\000"
  "\004\000\000\000\006\000\000\000\007\000\000\000\113\120\220\013"
  "\002\000\000\000\344\000\000\000\004\000\114\000\350\000\000\000"
  "\354\000\000\000\265\144\045\040\006\000\000\000\354\000\000\000"
  "\007\000\114\000\364\000\000\000\370\000\000\000\324\265\002\000"
  "\377\377\377\377\370\000\000\000\001\000\114\000\374\000\000\000"
  "\000\001\000\000\276\102\047\030\001\000\000\000\000\001\000\000"
  "\016\000\114\000\020\001\000\000\024\001\000\000\201\321\040\031"
  "\000\000\000\000\024\001\000\000\005\000\114\000\034\001\000\000"
  "\040\001\000\000\062\253\136\330\003\000\000\000\040\001\000\000"
  "\010\000\166\000\050\001\000\000\215\001\000\000\000\113\055\223"
  "\004\000\000\000\215\001\000\000\006\000\114\000\224\001\000\000"
  "\230\001\000\000\157\162\147\057\004\000\000\000\141\160\160\154"
  "\145\164\057\000\003\000\000\000\057\000\000\000\000\000\000\000"
  "\156\157\164\151\146\151\143\141\164\151\157\156\163\057\000\000"
  "\005\000\000\000\155\141\164\145\057\000\000\000\006\000\000\000"
  "\155\145\156\165\056\170\155\154\244\000\000\000\001\000\000\000"
  "\170\332\263\311\115\315\053\315\054\111\315\125\310\113\314\115"
  "\265\125\162\311\367\313\057\161\311\054\056\051\055\112\122\360"
  "\004\212\053\051\044\046\227\144\346\347\241\112\051\051\350\333"
  "\161\331\240\351\015\050\112\115\113\055\112\315\113\116\055\106"
  "\323\212\044\203\125\247\143\122\176\151\011\232\036\260\030\130"
  "\065\000\225\036\070\062\000\050\165\165\141\171\051\160\141\156"
  "\145\154\057\000\001\000\000\000" };
#endif /* !_MSC_VER */

static GStaticResource static_resource = { notification_applet_resource_data.data, sizeof (notification_applet_resource_data.data) - 1 /* nul terminator */, NULL, NULL, NULL };

G_MODULE_EXPORT
GResource *notification_applet_get_resource (void);
GResource *notification_applet_get_resource (void)
{
  return g_static_resource_get_resource (&static_resource);
}
/*
  If G_HAS_CONSTRUCTORS is true then the compiler support *both* constructors and
  destructors, in a usable way, including e.g. on library unload. If not you're on
  your own.

  Some compilers need #pragma to handle this, which does not work with macros,
  so the way you need to use this is (for constructors):

  #ifdef G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA
  #pragma G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(my_constructor)
  #endif
  G_DEFINE_CONSTRUCTOR(my_constructor)
  static void my_constructor(void) {
   ...
  }

*/

#ifndef __GTK_DOC_IGNORE__

#if  __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 7)

#define G_HAS_CONSTRUCTORS 1

#define G_DEFINE_CONSTRUCTOR(_func) static void __attribute__((constructor)) _func (void);
#define G_DEFINE_DESTRUCTOR(_func) static void __attribute__((destructor)) _func (void);

#elif defined (_MSC_VER) && (_MSC_VER >= 1500)
/* Visual studio 2008 and later has _Pragma */

#include <stdlib.h>

#define G_HAS_CONSTRUCTORS 1

/* We do some weird things to avoid the constructors being optimized
 * away on VS2015 if WholeProgramOptimization is enabled. First we
 * make a reference to the array from the wrapper to make sure its
 * references. Then we use a pragma to make sure the wrapper function
 * symbol is always included at the link stage. Also, the symbols
 * need to be extern (but not dllexport), even though they are not
 * really used from another object file.
 */

/* We need to account for differences between the mangling of symbols
 * for x86 and x64/ARM/ARM64 programs, as symbols on x86 are prefixed
 * with an underscore but symbols on x64/ARM/ARM64 are not.
 */
#ifdef _M_IX86
#define G_MSVC_SYMBOL_PREFIX "_"
#else
#define G_MSVC_SYMBOL_PREFIX ""
#endif

#define G_DEFINE_CONSTRUCTOR(_func) G_MSVC_CTOR (_func, G_MSVC_SYMBOL_PREFIX)
#define G_DEFINE_DESTRUCTOR(_func) G_MSVC_DTOR (_func, G_MSVC_SYMBOL_PREFIX)

#define G_MSVC_CTOR(_func,_sym_prefix) \
  static void _func(void); \
  extern int (* _array ## _func)(void);              \
  int _func ## _wrapper(void) { _func(); g_slist_find (NULL,  _array ## _func); return 0; } \
  __pragma(comment(linker,"/include:" _sym_prefix # _func "_wrapper")) \
  __pragma(section(".CRT$XCU",read)) \
  __declspec(allocate(".CRT$XCU")) int (* _array ## _func)(void) = _func ## _wrapper;

#define G_MSVC_DTOR(_func,_sym_prefix) \
  static void _func(void); \
  extern int (* _array ## _func)(void);              \
  int _func ## _constructor(void) { atexit (_func); g_slist_find (NULL,  _array ## _func); return 0; } \
   __pragma(comment(linker,"/include:" _sym_prefix # _func "_constructor")) \
  __pragma(section(".CRT$XCU",read)) \
  __declspec(allocate(".CRT$XCU")) int (* _array ## _func)(void) = _func ## _constructor;

#elif defined (_MSC_VER)

#define G_HAS_CONSTRUCTORS 1

/* Pre Visual studio 2008 must use #pragma section */
#define G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA 1
#define G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA 1

#define G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(_func) \
  section(".CRT$XCU",read)
#define G_DEFINE_CONSTRUCTOR(_func) \
  static void _func(void); \
  static int _func ## _wrapper(void) { _func(); return 0; } \
  __declspec(allocate(".CRT$XCU")) static int (*p)(void) = _func ## _wrapper;

#define G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(_func) \
  section(".CRT$XCU",read)
#define G_DEFINE_DESTRUCTOR(_func) \
  static void _func(void); \
  static int _func ## _constructor(void) { atexit (_func); return 0; } \
  __declspec(allocate(".CRT$XCU")) static int (* _array ## _func)(void) = _func ## _constructor;

#elif defined(__SUNPRO_C)

/* This is not tested, but i believe it should work, based on:
 * http://opensource.apple.com/source/OpenSSL098/OpenSSL098-35/src/fips/fips_premain.c
 */

#define G_HAS_CONSTRUCTORS 1

#define G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA 1
#define G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA 1

#define G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(_func) \
  init(_func)
#define G_DEFINE_CONSTRUCTOR(_func) \
  static void _func(void);

#define G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(_func) \
  fini(_func)
#define G_DEFINE_DESTRUCTOR(_func) \
  static void _func(void);

#else

/* constructors not supported for this compiler */

#endif

#endif /* __GTK_DOC_IGNORE__ */

#ifdef G_HAS_CONSTRUCTORS

#ifdef G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA
#pragma G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(resource_constructor)
#endif
G_DEFINE_CONSTRUCTOR(resource_constructor)
#ifdef G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA
#pragma G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(resource_destructor)
#endif
G_DEFINE_DESTRUCTOR(resource_destructor)

#else
#warning "Constructor not supported on this compiler, linking in resources will not work"
#endif

static void resource_constructor (void)
{
  g_static_resource_init (&static_resource);
}

static void resource_destructor (void)
{
  g_static_resource_fini (&static_resource);
}

==> mate-notification-daemon-1.26.1.tar.xz: mate-notification-daemon-1.26.1/src/capplet/mate-notification-applet-resources.c <==
#include <gio/gio.h>

#if defined (__ELF__) && ( __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 6))
# define SECTION __attribute__ ((section (".gresource.notification_applet"), aligned (8)))
#else
# define SECTION
#endif

static const SECTION union { const guint8 data[409]; const double alignment; void * const ptr;}  notification_applet_resource_data = { {
  0107, 0126, 0141, 0162, 0151, 0141, 0156, 0164, 0000, 0000, 0000, 0000, 0000, 0000, 0000, 0000, 
  0030, 0000, 0000, 0000, 0344, 0000, 0000, 0000, 0000, 0000, 0000, 0050, 0007, 0000, 0000, 0000, 
  0000, 0000, 0000, 0000, 0000, 0000, 0000, 0000, 0002, 0000, 0000, 0000, 0003, 0000, 0000, 0000, 
  0004, 0000, 0000, 0000, 0006, 0000, 0000, 0000, 0007, 0000, 0000, 0000, 0113, 0120, 0220, 0013, 
  0002, 0000, 0000, 0000, 0344, 0000, 0000, 0000, 0004, 0000, 0114, 0000, 0350, 0000, 0000, 0000, 
  0354, 0000, 0000, 0000, 0265, 0144, 0045, 0040, 0006, 0000, 0000, 0000, 0354, 0000, 0000, 0000, 
  0007, 0000, 0114, 0000, 0364, 0000, 0000, 0000, 0370, 0000, 0000, 0000, 0324, 0265, 0002, 0000, 
  0377, 0377, 0377, 0377, 0370, 0000, 0000, 0000, 0001, 0000, 0114, 0000, 0374, 0000, 0000, 0000, 
  0000, 0001, 0000, 0000, 0276, 0102, 0047, 0030, 0001, 0000, 0000, 0000, 0000, 0001, 0000, 0000, 
  0016, 0000, 0114, 0000, 0020, 0001, 0000, 0000, 0024, 0001, 0000, 0000, 0201, 0321, 0040, 0031, 
  0000, 0000, 0000, 0000, 0024, 0001, 0000, 0000, 0005, 0000, 0114, 0000, 0034, 0001, 0000, 0000, 
  0040, 0001, 0000, 0000, 0062, 0253, 0136, 0330, 0003, 0000, 0000, 0000, 0040, 0001, 0000, 0000, 
  0010, 0000, 0166, 0000, 0050, 0001, 0000, 0000, 0215, 0001, 0000, 0000, 0000, 0113, 0055, 0223, 
  0004, 0000, 0000, 0000, 0215, 0001, 0000, 0000, 0006, 0000, 0114, 0000, 0224, 0001, 0000, 0000, 
  0230, 0001, 0000, 0000, 0157, 0162, 0147, 0057, 0004, 0000, 0000, 0000, 0141, 0160, 0160, 0154, 
  0145, 0164, 0057, 0000, 0003, 0000, 0000, 0000, 0057, 0000, 0000, 0000, 0000, 0000, 0000, 0000, 
  0156, 0157, 0164, 0151, 0146, 0151, 0143, 0141, 0164, 0151, 0157, 0156, 0163, 0057, 0000, 0000, 
  0005, 0000, 0000, 0000, 0155, 0141, 0164, 0145, 0057, 0000, 0000, 0000, 0006, 0000, 0000, 0000, 
  0155, 0145, 0156, 0165, 0056, 0170, 0155, 0154, 0244, 0000, 0000, 0000, 0001, 0000, 0000, 0000, 
  0170, 0332, 0263, 0311, 0115, 0315, 0053, 0315, 0054, 0111, 0315, 0125, 0310, 0113, 0314, 0115, 
  0265, 0125, 0162, 0311, 0367, 0313, 0057, 0161, 0311, 0054, 0056, 0051, 0055, 0112, 0122, 0360, 
  0004, 0212, 0053, 0051, 0044, 0046, 0227, 0144, 0346, 0347, 0241, 0112, 0051, 0051, 0350, 0333, 
  0161, 0331, 0240, 0351, 0015, 0050, 0112, 0115, 0113, 0055, 0112, 0315, 0113, 0116, 0055, 0106, 
  0323, 0212, 0044, 0203, 0125, 0247, 0143, 0122, 0176, 0151, 0011, 0232, 0036, 0260, 0030, 0130, 
  0065, 0000, 0225, 0036, 0070, 0062, 0000, 0050, 0165, 0165, 0141, 0171, 0051, 0160, 0141, 0156, 
  0145, 0154, 0057, 0000, 0001, 0000, 0000, 0000
} };

static GStaticResource static_resource = { notification_applet_resource_data.data, sizeof (notification_applet_resource_data.data) - 1 /* nul terminator */, NULL, NULL, NULL };

G_MODULE_EXPORT
GResource *notification_applet_get_resource (void);
GResource *notification_applet_get_resource (void)
{
  return g_static_resource_get_resource (&static_resource);
}
/* GLIB - Library of useful routines for C programming
 * Copyright (C) 1995-1997  Peter Mattis, Spencer Kimball and Josh MacDonald
 *
 * SPDX-License-Identifier: LGPL-2.1-or-later
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <http://www.gnu.org/licenses/>.
 */

/*
 * Modified by the GLib Team and others 1997-2000.  See the AUTHORS
 * file for a list of people on the GLib Team.  See the ChangeLog
 * files for a list of changes.  These files are distributed with
 * GLib at ftp://ftp.gtk.org/pub/gtk/.
 */

#ifndef __G_CONSTRUCTOR_H__
#define __G_CONSTRUCTOR_H__

/*
  If G_HAS_CONSTRUCTORS is true then the compiler support *both* constructors and
  destructors, in a usable way, including e.g. on library unload. If not you're on
  your own.

  Some compilers need #pragma to handle this, which does not work with macros,
  so the way you need to use this is (for constructors):

  #ifdef G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA
  #pragma G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(my_constructor)
  #endif
  G_DEFINE_CONSTRUCTOR(my_constructor)
  static void my_constructor(void) {
   ...
  }

*/

#ifndef __GTK_DOC_IGNORE__

#if  __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 7)

#define G_HAS_CONSTRUCTORS 1

#define G_DEFINE_CONSTRUCTOR(_func) static void __attribute__((constructor)) _func (void);
#define G_DEFINE_DESTRUCTOR(_func) static void __attribute__((destructor)) _func (void);

#elif defined (_MSC_VER) && (_MSC_VER >= 1500)
/* Visual studio 2008 and later has _Pragma */

/*
 * Only try to include gslist.h if not already included via glib.h,
 * so that items using gconstructor.h outside of GLib (such as
 * GResources) continue to build properly.
 */
#ifndef __G_LIB_H__
#include "gslist.h"
#endif

#include <stdlib.h>

#define G_HAS_CONSTRUCTORS 1

/* We do some weird things to avoid the constructors being optimized
 * away on VS2015 if WholeProgramOptimization is enabled. First we
 * make a reference to the array from the wrapper to make sure its
 * references. Then we use a pragma to make sure the wrapper function
 * symbol is always included at the link stage. Also, the symbols
 * need to be extern (but not dllexport), even though they are not
 * really used from another object file.
 */

/* We need to account for differences between the mangling of symbols
 * for x86 and x64/ARM/ARM64 programs, as symbols on x86 are prefixed
 * with an underscore but symbols on x64/ARM/ARM64 are not.
 */
#ifdef _M_IX86
#define G_MSVC_SYMBOL_PREFIX "_"
#else
#define G_MSVC_SYMBOL_PREFIX ""
#endif

#define G_DEFINE_CONSTRUCTOR(_func) G_MSVC_CTOR (_func, G_MSVC_SYMBOL_PREFIX)
#define G_DEFINE_DESTRUCTOR(_func) G_MSVC_DTOR (_func, G_MSVC_SYMBOL_PREFIX)

#define G_MSVC_CTOR(_func,_sym_prefix) \
  static void _func(void); \
  extern int (* _array ## _func)(void);              \
  int _func ## _wrapper(void) { _func(); g_slist_find (NULL,  _array ## _func); return 0; } \
  __pragma(comment(linker,"/include:" _sym_prefix # _func "_wrapper")) \
  __pragma(section(".CRT$XCU",read)) \
  __declspec(allocate(".CRT$XCU")) int (* _array ## _func)(void) = _func ## _wrapper;

#define G_MSVC_DTOR(_func,_sym_prefix) \
  static void _func(void); \
  extern int (* _array ## _func)(void);              \
  int _func ## _constructor(void) { atexit (_func); g_slist_find (NULL,  _array ## _func); return 0; } \
   __pragma(comment(linker,"/include:" _sym_prefix # _func "_constructor")) \
  __pragma(section(".CRT$XCU",read)) \
  __declspec(allocate(".CRT$XCU")) int (* _array ## _func)(void) = _func ## _constructor;

#elif defined (_MSC_VER)

#define G_HAS_CONSTRUCTORS 1

/* Pre Visual studio 2008 must use #pragma section */
#define G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA 1
#define G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA 1

#define G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(_func) \
  section(".CRT$XCU",read)
#define G_DEFINE_CONSTRUCTOR(_func) \
  static void _func(void); \
  static int _func ## _wrapper(void) { _func(); return 0; } \
  __declspec(allocate(".CRT$XCU")) static int (*p)(void) = _func ## _wrapper;

#define G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(_func) \
  section(".CRT$XCU",read)
#define G_DEFINE_DESTRUCTOR(_func) \
  static void _func(void); \
  static int _func ## _constructor(void) { atexit (_func); return 0; } \
  __declspec(allocate(".CRT$XCU")) static int (* _array ## _func)(void) = _func ## _constructor;

#elif defined(__SUNPRO_C)

/* This is not tested, but i believe it should work, based on:
 * http://opensource.apple.com/source/OpenSSL098/OpenSSL098-35/src/fips/fips_premain.c
 */

#define G_HAS_CONSTRUCTORS 1

#define G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA 1
#define G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA 1

#define G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(_func) \
  init(_func)
#define G_DEFINE_CONSTRUCTOR(_func) \
  static void _func(void);

#define G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(_func) \
  fini(_func)
#define G_DEFINE_DESTRUCTOR(_func) \
  static void _func(void);

#else

/* constructors not supported for this compiler */

#endif

#endif /* __GTK_DOC_IGNORE__ */
#endif /* __G_CONSTRUCTOR_H__ */

#ifdef G_HAS_CONSTRUCTORS

#ifdef G_DEFINE_CONSTRUCTOR_NEEDS_PRAGMA
#pragma G_DEFINE_CONSTRUCTOR_PRAGMA_ARGS(notification_appletresource_constructor)
#endif
G_DEFINE_CONSTRUCTOR(notification_appletresource_constructor)
#ifdef G_DEFINE_DESTRUCTOR_NEEDS_PRAGMA
#pragma G_DEFINE_DESTRUCTOR_PRAGMA_ARGS(notification_appletresource_destructor)
#endif
G_DEFINE_DESTRUCTOR(notification_appletresource_destructor)

#else
#warning "Constructor not supported on this compiler, linking in resources will not work"
#endif

static void notification_appletresource_constructor (void)
{
  g_static_resource_init (&static_resource);
}

static void notification_appletresource_destructor (void)
{
  g_static_resource_fini (&static_resource);
}
